==> savane-1.4.tar.gz: savane-1.4/frontend/php/siteadmin/search.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: search.php 5187 2005-12-01 16:22:29Z yeupou $
//
// 
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2003 (c) Free Software Foundation
// 
// The Savane project is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// The Savane project is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Savane project; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//

require "../include/pre.php";

if ($search == "") {
	exit_error("Refusing to display whole DB","That would display whole DB.  Please use a CLI query if you wish to do this.");
}
site_admin_header(array('title'=>'Savannah Admin Search','context'=>'admgroup'));

// FIXME: not conform to the CODING STYLE

?>

<p><B>User/Group/Category Maintenance</B>
<br />
<b> Search Criteria: </b> 

<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: search.php 5187 2005-12-01 16:22:29Z yeupou $
// print " \"%$search%\" <p>"; 




if ($usersearch) {

	$sql = "select distinctrow * from user where user_id like '%$search%' or user_name like '%$search%' or email like '%$search%' or realname like '%$search%'";
	$result = db_query($sql) or exit_db(db_error());
	if (db_numrows($result) < 1) {
		print "No matches.<p><a href=\"/admin/\">Back</a>";

	}
	else {

		print "<table border=\"1\">";
		print "<tr><th>UserName</th><th>User's Name</th></tr>\n\n";

		while ($row = db_fetch_array($result)) {
			print "<tr><td><a href=\"usergroup.php?user_id=$row[user_id]\">$row[user_name]</a></td><td>$row[realname]</td></tr>\n"; 
		}
		print "</table>";

	} 
} 


$HTML->footer(array());
?>

==> savane-2.0.tar.gz: savane-2.0/frontend/php/siteadmin/search.php <==
<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: search.php 5557 2006-08-14 08:25:30Z toddy $
//
// 
// Copyright 1999-2000 (c) The SourceForge Crew
//
//
//  Copyright 2000-2003 (c) Free Software Foundation
// 
// The Savane project is free software; you can redistribute it and/or
// modify it under the terms of the GNU General Public License
// as published by the Free Software Foundation; either version 2
// of the License, or (at your option) any later version.
//
// The Savane project is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with the Savane project; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
//
//

require "../include/pre.php";

if ($search == "") {
	exit_error("Refusing to display whole DB","That would display whole DB.  Please use a CLI query if you wish to do this.");
}
site_admin_header(array('title'=>'Savannah Admin Search','context'=>'admgroup'));

// FIXME: not conform to the CODING STYLE

?>

<p><strong>User/Group/Category Maintenance</strong>
<br />
<strong> Search Criteria: </strong> 

<?php
// This file is part of the Savane project
// <http://gna.org/projects/savane/>
//
// $Id: search.php 5557 2006-08-14 08:25:30Z toddy $
// print " \"%$search%\" <p>"; 




if ($usersearch) {

	$sql = "select distinctrow * from user where user_id like '%$search%' or user_name like '%$search%' or email like '%$search%' or realname like '%$search%'";
	$result = db_query($sql) or exit_db(db_error());
	if (db_numrows($result) < 1) {
		print "No matches.<p><a href=\"/admin/\">Back</a>";

	}
	else {

		print "<table border=\"1\">";
		print "<tr><th>UserName</th><th>User's Name</th></tr>\n\n";

		while ($row = db_fetch_array($result)) {
			print "<tr><td><a href=\"usergroup.php?user_id=$row[user_id]\">$row[user_name]</a></td><td>$row[realname]</td></tr>\n"; 
		}
		print "</table>";

	} 
} 


$HTML->footer(array());
?>
